@@ -6,6 +6,7 @@ from scipy.sparse import coo_matrix
 from karateclub.estimator import Estimator
 from sklearn.decomposition import TruncatedSVD
 
+
 class FeatherNode(Estimator):
     r"""An implementation of `"FEATHER-N" <https://arxiv.org/abs/2005.07959>`_
     from the CIKM '20 paper "Characteristic Functions on Graphs: Birds of a Feather,
@@ -21,8 +22,16 @@ class FeatherNode(Estimator):
         order (int): Scale - number of adjacency matrix powers. Default is 5.
         seed (int): Random seed value. Default is 42.
     """
-    def __init__(self, reduction_dimensions: int=64, svd_iterations: int=20,
-                 theta_max: float=2.5, eval_points: int=25, order: int=5, seed: int=42):
+
+    def __init__(
+        self,
+        reduction_dimensions: int = 64,
+        svd_iterations: int = 20,
+        theta_max: float = 2.5,
+        eval_points: int = 25,
+        order: int = 5,
+        seed: int = 42,
+    ):
 
         self.reduction_dimensions = reduction_dimensions
         self.svd_iterations = svd_iterations
@@ -42,12 +51,13 @@ class FeatherNode(Estimator):
             * **D_inverse** *(Scipy array)* - Diagonal inverse degree matrix.
         """
         index = np.arange(graph.number_of_nodes())
-        values = np.array([1.0/graph.degree[node] for node in range(graph.number_of_nodes())])
+        values = np.array(
+            [1.0 / graph.degree[node] for node in range(graph.number_of_nodes())]
+        )
         shape = (graph.number_of_nodes(), graph.number_of_nodes())
         D_inverse = scipy.sparse.coo_matrix((values, (index, index)), shape=shape)
         return D_inverse
 
-
     def _create_A_tilde(self, graph):
         """
         Creating a sparse normalized adjacency matrix.
@@ -62,7 +72,6 @@ class FeatherNode(Estimator):
         A_tilde = D_inverse.dot(A)
         return A_tilde
 
-
     def _reduce_dimensions(self, X):
         """
         Using Truncated SVD.
@@ -73,14 +82,15 @@ class FeatherNode(Estimator):
         Return types:
             * **X** *(Numpy array)* - The reduced feature matrix of nodes.
         """
-        svd = TruncatedSVD(n_components=self.reduction_dimensions,
-                           n_iter=self.svd_iterations,
-                           random_state=self.seed)
+        svd = TruncatedSVD(
+            n_components=self.reduction_dimensions,
+            n_iter=self.svd_iterations,
+            random_state=self.seed,
+        )
         svd.fit(X)
         X = svd.transform(X)
         return X
 
-
     def _create_reduced_features(self, X):
         """
         Creating a dense reduced node feature matrix.
@@ -121,7 +131,6 @@ class FeatherNode(Estimator):
             self._feature_blocks.append(X)
         self._feature_blocks = np.concatenate(self._feature_blocks, axis=1)
 
-
     def get_embedding(self) -> np.array:
         r"""Getting the node embedding.
 
