@@ -3,6 +3,7 @@ import networkx as nx
 from sklearn.preprocessing import normalize
 from karateclub.estimator import Estimator
 
+
 class NEU(Estimator):
     r"""An implementation of `"NEU" <https://www.ijcai.org/Proceedings/2017/0544.pdf>`_
     from the IJCAI 17 paper "Fast Network Embedding Enhancement via High Order Proximity Approximation".
@@ -15,7 +16,8 @@ class NEU(Estimator):
         T (int): Number of iterations. Default is 1.
         seed (int): Random seed value. Default is 42.
     """
-    def __init__(self, L1: float=0.5, L2: float=0.25, T: int=1, seed: int=42):
+
+    def __init__(self, L1: float = 0.5, L2: float = 0.25, T: int = 1, seed: int = 42):
         self.iterations = T
         self.L1 = L1
         self.L2 = L2
@@ -30,7 +32,7 @@ class NEU(Estimator):
             normalized_embedding (Numpy array): An array containing a normalized embedding
         """
         norms = np.linalg.norm(original_embedding, axis=1)
-        normalized_embedding = (original_embedding.T/norms).T
+        normalized_embedding = (original_embedding.T / norms).T
         return normalized_embedding
 
     def _update_embedding(self, graph, original_embedding):
@@ -44,11 +46,13 @@ class NEU(Estimator):
         """
         embedding = self._normalize_embedding(original_embedding)
         adjacency = nx.adjacency_matrix(graph, nodelist=range(graph.number_of_nodes()))
-        normalized_adjacency = normalize(adjacency, norm='l1', axis=1)
+        normalized_adjacency = normalize(adjacency, norm="l1", axis=1)
         for _ in range(self.iterations):
-            embedding = (embedding + 
-                         self.L1*(normalized_adjacency @ embedding) + 
-                         self.L2*(normalized_adjacency @ (normalized_adjacency @ embedding)))
+            embedding = (
+                embedding
+                + self.L1 * (normalized_adjacency @ embedding)
+                + self.L2 * (normalized_adjacency @ (normalized_adjacency @ embedding))
+            )
         return embedding
 
     def fit(self, graph: nx.classes.graph.Graph, model: Estimator):
@@ -64,7 +68,7 @@ class NEU(Estimator):
         self.model = model
         self.model.fit(graph)
         original_embedding = self.model.get_embedding()
-        self._embedding = self._update_embedding(graph, original_embedding)    
+        self._embedding = self._update_embedding(graph, original_embedding)
 
     def get_embedding(self) -> np.array:
         r"""Getting the node embedding.
