@@ -1,8 +1,12 @@
-import numpy as np
+from typing import List
+
 import networkx as nx
+import numpy as np
 from gensim.models.word2vec import Word2Vec
-from karateclub.utils.walker import BiasedRandomWalker
+
 from karateclub.estimator import Estimator
+from karateclub.utils.walker import BiasedRandomWalker
+
 
 class Node2Vec(Estimator):
     r"""An implementation of `"Node2Vec" <https://cs.stanford.edu/~jure/pubs/node2vec-kdd16.pdf>`_
@@ -24,9 +28,23 @@ class Node2Vec(Estimator):
         min_count (int): Minimal count of node occurrences. Default is 1.
         seed (int): Random seed value. Default is 42.
     """
-    def __init__(self, walk_number: int=10, walk_length: int=80, p: float=1.0, q: float=1.0,
-                 dimensions: int=128, workers: int=4, window_size: int=5, epochs: int=1,
-                 learning_rate: float=0.05, min_count: int=1, seed: int=42):
+    _embedding: List[np.ndarray]
+
+    def __init__(
+        self,
+        walk_number: int = 10,
+        walk_length: int = 80,
+        p: float = 1.0,
+        q: float = 1.0,
+        dimensions: int = 128,
+        workers: int = 4,
+        window_size: int = 5,
+        epochs: int = 1,
+        learning_rate: float = 0.05,
+        min_count: int = 1,
+        seed: int = 42,
+    ):
+        super(Node2Vec, self).__init__()
 
         self.walk_number = walk_number
         self.walk_length = walk_length
@@ -52,19 +70,20 @@ class Node2Vec(Estimator):
         walker = BiasedRandomWalker(self.walk_length, self.walk_number, self.p, self.q)
         walker.do_walks(graph)
 
-        model = Word2Vec(walker.walks,
-                         hs=1,
-                         alpha=self.learning_rate,
-                         epochs=self.epochs,
-                         vector_size=self.dimensions,
-                         window=self.window_size,
-                         min_count=self.min_count,
-                         workers=self.workers,
-                         seed=self.seed)
-
-        num_of_nodes = graph.number_of_nodes()
-        self._embedding = [model.wv[str(n)] for n in range(num_of_nodes)]
+        model = Word2Vec(
+            walker.walks,
+            hs=1,
+            alpha=self.learning_rate,
+            epochs=self.epochs,
+            vector_size=self.dimensions,
+            window=self.window_size,
+            min_count=self.min_count,
+            workers=self.workers,
+            seed=self.seed,
+        )
 
+        n_nodes = graph.number_of_nodes()
+        self._embedding = [model.wv[str(n)] for n in range(n_nodes)]
 
     def get_embedding(self) -> np.array:
         r"""Getting the node embedding.
